// 
// Copyright (c) Microsoft and contributors.  All rights reserved.
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//   http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// 
// See the License for the specific language governing permissions and
// limitations under the License.
// 

// Warning: This code was generated by a tool.
// 
// Changes to this file may cause incorrect behavior and will be lost if the
// code is regenerated.

using System.Threading;
using System.Threading.Tasks;
using Microsoft.Azure.Management.Internal.Resources.Models;

namespace Microsoft.Azure.Management.Internal.Resources
{
    /// <summary>
    /// Operations for managing preview features.
    /// </summary>
    public partial interface IFeatures
    {
        /// <summary>
        /// Get all features under the subscription.
        /// </summary>
        /// <param name='resourceProviderNamespace'>
        /// Namespace of the resource provider.
        /// </param>
        /// <param name='featureName'>
        /// Previewed feature name in the resource provider.
        /// </param>
        /// <param name='cancellationToken'>
        /// Cancellation token.
        /// </param>
        /// <returns>
        /// Previewed feature information.
        /// </returns>
        Task<FeatureResponse> GetAsync(string resourceProviderNamespace, string featureName, CancellationToken cancellationToken);
        
        /// <summary>
        /// Gets a list of previewed features of a resource provider.
        /// </summary>
        /// <param name='resourceProviderNamespace'>
        /// The namespace of the resource provider.
        /// </param>
        /// <param name='cancellationToken'>
        /// Cancellation token.
        /// </param>
        /// <returns>
        /// List of previewed features.
        /// </returns>
        Task<FeatureOperationsListResult> ListAsync(string resourceProviderNamespace, CancellationToken cancellationToken);
        
        /// <summary>
        /// Gets a list of previewed features for all the providers in the
        /// current subscription.
        /// </summary>
        /// <param name='cancellationToken'>
        /// Cancellation token.
        /// </param>
        /// <returns>
        /// List of previewed features.
        /// </returns>
        Task<FeatureOperationsListResult> ListAllAsync(CancellationToken cancellationToken);
        
        /// <summary>
        /// Gets a list of previewed features of a subscription.
        /// </summary>
        /// <param name='nextLink'>
        /// NextLink from the previous successful call to List operation.
        /// </param>
        /// <param name='cancellationToken'>
        /// Cancellation token.
        /// </param>
        /// <returns>
        /// List of previewed features.
        /// </returns>
        Task<FeatureOperationsListResult> ListAllNextAsync(string nextLink, CancellationToken cancellationToken);
        
        /// <summary>
        /// Gets a list of previewed features of a resource provider.
        /// </summary>
        /// <param name='nextLink'>
        /// NextLink from the previous successful call to List operation.
        /// </param>
        /// <param name='cancellationToken'>
        /// Cancellation token.
        /// </param>
        /// <returns>
        /// List of previewed features.
        /// </returns>
        Task<FeatureOperationsListResult> ListNextAsync(string nextLink, CancellationToken cancellationToken);
        
        /// <summary>
        /// Registers for a previewed feature of a resource provider.
        /// </summary>
        /// <param name='resourceProviderNamespace'>
        /// Namespace of the resource provider.
        /// </param>
        /// <param name='featureName'>
        /// Previewed feature name in the resource provider.
        /// </param>
        /// <param name='cancellationToken'>
        /// Cancellation token.
        /// </param>
        /// <returns>
        /// Previewed feature information.
        /// </returns>
        Task<FeatureResponse> RegisterAsync(string resourceProviderNamespace, string featureName, CancellationToken cancellationToken);
    }
}
